Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Runnable ¶
type Runnable interface {
Init(interface{}, *golog.Loggers) error
Run() error
Stop() error
CleanUp() error
}
Runnable provides method signatures to manage the execution flow of the server and external resources
type RunnableGormable ¶
RunnableGormable provides method signatures for a gorm manager that is Runnable
type RunnableRabbit ¶
type RunnableRabbit interface {
Runnable
amqpmanager.Connectable
}
Click to show internal directories.
Click to hide internal directories.